type SourceReader = {
    read: Function;
};
type SourceReadable = {
    getReader: (...args: any) => {
        read: Function;
    };
};
type Source = SourceReader | SourceReadable | AsyncIterable<Uint8Array> | Iterable<Uint8Array>;
type StreamResult = {
    filename: string;
    reader: AsyncIterable<Uint8Array>;
};
type StreamResults = StreamResult[];
type IndexerOffsetLength = {
    offset: number;
    recordLength: number;
};
type Request = {
    method: string;
    url: string;
    headers: Map<string, string> | Headers;
    postData?: Uint8Array | string | undefined | null;
    requestBody?: any;
};
type Response = Request;

declare function binaryToString(data: Uint8Array | string | undefined | null): string;
declare function rxEscape(string: string): string;
declare function getSurt(url: string): string;
declare function postToGetUrl(request: Request): boolean;
declare function appendRequestQuery(url: string, query: string, method: string): string;
declare function jsonToQueryParams(json: unknown, ignoreInvalid?: boolean): URLSearchParams;
declare function mfdToQueryParams(mfd: string | Uint8Array | null | undefined, contentType: string): URLSearchParams;
declare function jsonToQueryString(json?: string | Record<string, unknown> | undefined | null, ignoreInvalid?: boolean): string;
declare function mfdToQueryString(mfd: string | Uint8Array | undefined | null, contentType: string): string;
declare function concatChunks(chunks: Uint8Array[], size: number): Uint8Array;
declare function splitChunk(chunk: Uint8Array, inx: number): [Uint8Array, Uint8Array];
declare function UTFToLatin1(value: string): string;
declare function latin1ToUTF(str: string): string;
declare function multiValueHeader(name: string, value: string[]): string;
declare class HeadersMultiMap extends Map<string, string> {
    constructor(headersInit?: HeadersInit);
    getMultiple(name: string): string[] | undefined;
    append(name: string, value: string): void;
    [Symbol.iterator](): IterableIterator<[string, string]>;
}

export { HeadersMultiMap as H, IndexerOffsetLength as I, Request as R, Source as S, UTFToLatin1 as U, StreamResults as a, binaryToString as b, appendRequestQuery as c, jsonToQueryString as d, mfdToQueryString as e, concatChunks as f, getSurt as g, multiValueHeader as h, SourceReader as i, jsonToQueryParams as j, SourceReadable as k, latin1ToUTF as l, mfdToQueryParams as m, StreamResult as n, Response as o, postToGetUrl as p, rxEscape as r, splitChunk as s };
